blockptr-to-tdesc

blockptr-to-tdesc is a Migrations, upgrades & porting skill for AI agents, published by intel in the intel-xpu-backend-for-triton repository on GitHub. Skillspace rates blockptr-to-tdesc C (72/100) and it passed the safety scan; the rating is based on static analysis only.

Translate a Triton kernel from the deprecated block-pointer API (tl.make_block_ptr / tl.advance / tl.load(boundary_check=...)) into an equivalent kernel using the modern device-side tensor-descriptor API (tl.make_tensor_descriptor / desc.load / desc.store) for the Intel XPU backend. Use this skill whenever the user wants to migrate, convert, translate, port, modernize, or "update" a kernel from block pointers to tensor descriptors; whenever they mention tl.make_block_ptr or tl.advance and ask for a modern/non-deprecated equivalent; whenever they ask how to use tensor descriptors in a kernel that currently uses block pointers; or when they paste a kernel using block pointers and ask how to speed it up or make it use DPAS / 2D block I/O on Intel GPU (PVC/BMG). Produce the descriptor form the XPU backend can lower efficiently, not just any form that compiles.

Grade
C
Quality
72 / 100
Safety
Passed
GitHub stars
258

Unproven: rated by static analysis only, not yet compared head-to-head.

This rating describes the version of the repository we crawled; it may have changed since, so go by its current files.

Our review

Architecture
84 / 100
Maturity
Structured: ships references or scripts
Security scan
No issues found
License
MIT
Adoption
Adopted by 0 other repositories, in 0 collections

Not checked yet

  • Not judged on the rubric yet (not a contender in its category)
  • No blind task eval yet
  • Scope (portable / vendor / repo-internal) not assessed; only the top of each category is read for scope
  • Sibling files (scripts, references) not fetched; security scan covers SKILL.md only

Skillspace indexes and rates this skill; it does not host or endorse it. Run third-party skills at your own risk.